Page 64 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 64

Home

    Around 1800 a study was made on education in
    America that concluded, "Most young Americans .. . can
    read, write and cipher. Not more than four in a thousand
    are unable to write legibly — even neatly.”

    This high rate of literacy was a direct result of the
    religions leaders placing a strong emphasis upon the
    importance of being able to read the Bible. There were
    no public schools at this time.

    Because of their knowledge of history, secular and
    religious, the Founding Fathers had a profound faith in
    Divine Providence and a strong distrust in government.
    Thus, they set out to establish a system of government
    that would set men free to work out their own destiny by
    binding rulers down "with the chains of the

    binding rulers
    Constitution."

    rulers

    down

    "with

    the

    chains

    The United States Constitution was not something
    hammered out over night, but was carefully written after
    much consideration and debate. The war with Britain

    ended on October 19, 1781, but the Constitution was not
    ratified until June 1788. Two years later, December
    1791, the Bill of Rights was adopted.

    To understand better the events leading up to the
    founding of the American Republic, and why the
    Founding Fathers gave us the kind of government they
    did, it will be helpful to examine the Old World View of

    man and government.
    This view was largely a fatalistic view that the
    individual is helpless to determine his destiny, that he is

    59

    The American Republic